@@ -69,7 +69,10 @@
 
 #include "channel.h"
 
-
+#if defined(_MSC_VER)
+/* needed to workaround a warning / prototype/dll inconsistency crap */
+#define vsnprintf unrl_vsnprintf
+#endif
 
 extern MODVAR int sendanyways;
 
@@ -367,6 +370,12 @@ typedef unsigned int u_int32_t;	/* XXX Hope this works! */
 #define PROTO_NAMESX	0x4000  /* Send all rights in NAMES output */
 #define PROTO_CLK		0x8000	/* Send cloaked host in the NICK command (regardless of +x/-x) */
 #define PROTO_UHNAMES	0x10000  /* Send n!u@h in NAMES */
+#define PROTO_CLICAP	0x20000  /* client capability negotiation in process */
+#define PROTO_STARTTLS	0x40000	 /* client supports STARTTLS */
+#define PROTO_SASL	0x80000  /* client is doing SASL */
+#define PROTO_AWAY_NOTIFY	0x100000	/* client supports away-notify */
+#define PROTO_ACCOUNT_NOTIFY	0x200000	/* client supports account-notify */
+#define PROTO_MLOCK		0x400000	/* server supports MLOCK */
 
 /*
  * flags macros.
@@ -449,11 +458,7 @@ typedef unsigned int u_int32_t;	/* XXX Hope this works! */
 #ifdef USE_SSL
 #define IsSSL(x)		IsSecure(x)
 #endif
-#ifdef NOSPOOF
 #define	IsNotSpoof(x)		((x)->nospoof == 0)
-#else
-#define IsNotSpoof(x)           (1)
-#endif
 
 #define GetHost(x)			(IsHidden(x) ? (x)->user->virthost : (x)->user->realhost)
 #define GetIP(x)			((x->user && x->user->ip_str) ? x->user->ip_str : (MyConnect(x) ? Inet_ia2p(&x->ip) : NULL))
@@ -802,7 +807,15 @@ struct User {
 	Link *silence;		/* chain of silence pointer blocks */
 	Link *dccallow;		/* chain of dccallowed entries */
 	char *away;		/* pointer to away message */
-	u_int32_t servicestamp;	/* Services' time stamp variable */
+
+	/*
+	 * svid: a value that is assigned by services to this user record.
+	 * in previous versions of Unreal, this was strictly a timestamp value,
+	 * which is less useful in the modern world of IRC where nicks are grouped to
+	 * accounts, so it is now a string.
+	 */
+	char svid[NICKLEN + 1];
+
 	signed char refcnt;	/* Number of times this block is referenced */
 	unsigned short joined;		/* number of channels joined */
 	char username[USERLEN + 1];
@@ -1020,9 +1033,7 @@ struct Client {
 	short lastsq;		/* # of 2k blocks when sendqueued called last */
 	dbuf sendQ;		/* Outgoing message queue--if socket full */
 	dbuf recvQ;		/* Hold for data incoming yet to be parsed */
-#ifdef NOSPOOF
 	u_int32_t nospoof;	/* Anti-spoofing random number */
-#endif
 	int proto;		/* ProtoCtl options */
 	long sendM;		/* Statistics: protocol messages send */
 	long sendK;		/* Statistics: total k-bytes send */
@@ -1062,6 +1073,11 @@ struct Client {
 	TS   cputime;
 #endif
 	char *error_str;	/* Quit reason set by dead_link in case of socket/buffer error */
+
+	char sasl_agent[NICKLEN + 1];
+	unsigned char sasl_out;
+	unsigned char sasl_complete;
+	u_short sasl_cookie;
 };
 
 
@@ -1214,7 +1230,7 @@ struct _configitem_oper {
 	anAuthStruct	 *auth;
 	ConfigItem_class *class;
 	ConfigItem	 *from;
-	unsigned long	 modes;
+	unsigned long	 modes, require_modes;
 	long		 oflags;
 	int			maxlogins;
 };
@@ -1367,14 +1383,14 @@ struct _configitem_deny_version {
 struct _configitem_deny_channel {
 	ConfigItem		*prev, *next;
 	ConfigFlag		flag;
-	char			*channel, *reason, *redirect;
+	char			*channel, *reason, *redirect, *class;
 	unsigned char	warn;
 };
 
 struct _configitem_allow_channel {
 	ConfigItem		*prev, *next;
 	ConfigFlag		flag;
-	char			*channel;
+	char			*channel, *class;
 };
 
 struct _configitem_allow_dcc {
@@ -1429,9 +1445,21 @@ struct _configitem_alias_format {
 	regex_t expr;
 };
 
+/**
+ * In a rehash scenario, conf_include will contain all of the included
+ * configs that are actually in use. It also will contain includes
+ * that are being processed so that the configuration may be updated.
+ * INCLUDE_NOTLOADED is set on all of the config files that are being
+ * loaded and unset on already-loaded files. See
+ * unload_loaded_includes() and load_includes().
+ */
 #define INCLUDE_NOTLOADED  0x1
 #define INCLUDE_REMOTE     0x2
 #define INCLUDE_DLQUEUED   0x4
+/**
+ * Marks that an include was loaded without error. This seems to
+ * overlap with the INCLUDE_NOTLOADED meaning(?). --binki
+ */
 #define INCLUDE_USED       0x8
 	
 struct _configitem_include {
@@ -1442,6 +1470,8 @@ struct _configitem_include {
 	char *url;
 	char *errorbuf;
 #endif
+	char *included_from;
+	int included_from_line;
 };
 
 struct _configitem_help {
@@ -1615,6 +1645,7 @@ struct Channel {
 #ifdef JOINTHROTTLE
 	aJFlood *jflood;
 #endif
+	char *mode_lock;
 	char chname[1];
 };
 
